##  GRAPH_RULE_CONSTRAINT
For this relation to work, at least one of the involved ServiceNow tables needs to have a Graph Rule Constraint configured (see above). The respective Graph Rule that is configured to constraint the number of records to be mapped will then be used to model this very graph as a relation in SAP LeanIX.
This relation type does not need any additional configuration.
